src/eric7/DebugClients/Python/ModuleLoader.py

branch
server
changeset 10704
27d21e5163b8
parent 10683
779cda568acb
child 11090
f5f5f5803935
diff -r 306373ccf8fd -r 27d21e5163b8 src/eric7/DebugClients/Python/ModuleLoader.py
--- a/src/eric7/DebugClients/Python/ModuleLoader.py	Wed Apr 10 17:03:56 2024 +0200
+++ b/src/eric7/DebugClients/Python/ModuleLoader.py	Wed May 15 10:45:50 2024 +0200
@@ -100,16 +100,16 @@
 
         return module
 
-    def find_spec(self, fullname, path, target=None):  # noqa: U100
+    def find_spec(self, fullname, _path, target=None):  # noqa: U100
         """
         Public method returning the module spec.
 
         @param fullname name of the module to be loaded
         @type str
-        @param path path to resolve the module name
+        @param _path path to resolve the module name (unused)
         @type str
         @param target module object to use for a more educated guess
             about what spec to return
         @type module
         @return module spec object pointing to the module loader
         @rtype ModuleSpec
@@ -100,16 +100,16 @@
         @type str
         @param target module object to use for a more educated guess
-            about what spec to return
+            about what spec to return (unused)
         @type module
         @return module spec object pointing to the module loader

eric ide

mercurial